@@ -21,7 +21,7 @@ import (
 	"io"
 	"time"
 
-	"github.com/dolthub/go-mysql-server/sql"
+	types2 "github.com/dolthub/go-mysql-server/sql/types"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/diff"
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
@@ -661,7 +661,7 @@ func newConstraintViolationsLoadedTable(ctx context.Context, tblName, idxName st
 			IsUserDefined: false,
 			Comment:       "",
 		}
-		pkIdx := schema.NewIndex("", pkCols.SortedTags, pkCols.SortedTags, pkIdxColl, pkIdxProps)
+		pkIdx := schema.NewIndex("", pkCols.Tags, pkCols.Tags, pkIdxColl, pkIdxProps)
 		return &constraintViolationsLoadedTable{
 			TableName:   trueTblName,
 			Table:       tbl,
@@ -774,7 +774,7 @@ func jsonDataToNomsValue(ctx context.Context, vrw types.ValueReadWriter, data []
 	if err := json.Unmarshal(data, &doc); err != nil {
 		return types.JSON{}, err
 	}
-	sqlDoc := sql.JSONDocument{Val: doc}
+	sqlDoc := types2.JSONDocument{Val: doc}
 	nomsJson, err := json2.NomsJSONFromJSONValue(ctx, vrw, sqlDoc)
 	if err != nil {
 		return types.JSON{}, err
