@@ -20,6 +20,7 @@ import (
 	"time"
 
 	"github.com/dolthub/go-mysql-server/sql"
+	types2 "github.com/dolthub/go-mysql-server/sql/types"
 	"github.com/dolthub/vitess/go/sqltypes"
 
 	"github.com/dolthub/dolt/go/store/types"
@@ -38,9 +39,9 @@ type datetimeType struct {
 
 var _ TypeInfo = (*datetimeType)(nil)
 var (
-	DateType      = &datetimeType{sql.Date}
-	DatetimeType  = &datetimeType{sql.Datetime}
-	TimestampType = &datetimeType{sql.Timestamp}
+	DateType      = &datetimeType{types2.Date}
+	DatetimeType  = &datetimeType{types2.Datetime}
+	TimestampType = &datetimeType{types2.Timestamp}
 )
 
 func CreateDatetimeTypeFromParams(params map[string]string) (TypeInfo, error) {
