@@ -20,6 +20,7 @@ import (
 	"strconv"
 
 	"github.com/dolthub/go-mysql-server/sql"
+	types2 "github.com/dolthub/go-mysql-server/sql/types"
 
 	"github.com/dolthub/dolt/go/store/types"
 )
@@ -32,7 +33,7 @@ type yearType struct {
 
 var _ TypeInfo = (*yearType)(nil)
 
-var YearType = &yearType{sql.Year}
+var YearType = &yearType{types2.Year}
 
 // ConvertNomsValueToValue implements TypeInfo interface.
 func (ti *yearType) ConvertNomsValueToValue(v types.Value) (interface{}, error) {
