@@ -156,7 +156,7 @@ func (dtf *DiffTableFunction) RowIter(ctx *sql.Context, _ sql.Row) (sql.RowIter,
 		return nil, err
 	}
 
-	sqledb, ok := dtf.database.(Database)
+	sqledb, ok := dtf.database.(SqlDatabase)
 	if !ok {
 		return nil, fmt.Errorf("unable to get dolt database")
 	}
@@ -166,7 +166,7 @@ func (dtf *DiffTableFunction) RowIter(ctx *sql.Context, _ sql.Row) (sql.RowIter,
 		return nil, err
 	}
 
-	ddb := sqledb.GetDoltDB()
+	ddb := sqledb.DbData().Ddb
 	dp := dtables.NewDiffPartition(dtf.tableDelta.ToTable, dtf.tableDelta.FromTable, toCommitStr, fromCommitStr, dtf.toDate, dtf.fromDate, dtf.tableDelta.ToSch, dtf.tableDelta.FromSch)
 
 	return NewDiffTableFunctionRowIterForSinglePartition(*dp, ddb, dtf.joiner), nil
@@ -200,7 +200,7 @@ type refDetails struct {
 
 // loadDetailsForRef loads the root, hash, and timestamp for the specified from
 // and to ref values
-func loadDetailsForRefs(ctx *sql.Context, fromRef, toRef, dotRef interface{}, db Database) (*refDetails, *refDetails, error) {
+func loadDetailsForRefs(ctx *sql.Context, fromRef, toRef, dotRef interface{}, db SqlDatabase) (*refDetails, *refDetails, error) {
 	fromCommitStr, toCommitStr, err := loadCommitStrings(ctx, fromRef, toRef, dotRef, db)
 	if err != nil {
 		return nil, nil, err
@@ -221,7 +221,7 @@ func loadDetailsForRefs(ctx *sql.Context, fromRef, toRef, dotRef interface{}, db
 	return fromDetails, toDetails, nil
 }
 
-func resolveCommitStrings(ctx *sql.Context, fromRef, toRef, dotRef interface{}, db Database) (string, string, error) {
+func resolveCommitStrings(ctx *sql.Context, fromRef, toRef, dotRef interface{}, db SqlDatabase) (string, string, error) {
 	if dotRef != nil {
 		dotStr, err := interfaceToString(dotRef)
 		if err != nil {
@@ -238,12 +238,12 @@ func resolveCommitStrings(ctx *sql.Context, fromRef, toRef, dotRef interface{},
 				return "", "", err
 			}
 
-			rightCm, err := resolveCommit(ctx, db.ddb, headRef, refs[0])
+			rightCm, err := resolveCommit(ctx, db.DbData().Ddb, headRef, refs[0])
 			if err != nil {
 				return "", "", err
 			}
 
-			leftCm, err := resolveCommit(ctx, db.ddb, headRef, refs[1])
+			leftCm, err := resolveCommit(ctx, db.DbData().Ddb, headRef, refs[1])
 			if err != nil {
 				return "", "", err
 			}
@@ -275,7 +275,7 @@ func resolveCommitStrings(ctx *sql.Context, fromRef, toRef, dotRef interface{},
 
 // loadCommitStrings gets the to and from commit strings, using the common
 // ancestor as the from commit string for three dot diff
-func loadCommitStrings(ctx *sql.Context, fromRef, toRef, dotRef interface{}, db Database) (string, string, error) {
+func loadCommitStrings(ctx *sql.Context, fromRef, toRef, dotRef interface{}, db SqlDatabase) (string, string, error) {
 	fromStr, toStr, err := resolveCommitStrings(ctx, fromRef, toRef, dotRef, db)
 	if err != nil {
 		return "", "", err
@@ -398,7 +398,7 @@ func (dtf *DiffTableFunction) generateSchema(ctx *sql.Context, fromCommitVal, to
 		return nil
 	}
 
-	sqledb, ok := dtf.database.(Database)
+	sqledb, ok := dtf.database.(SqlDatabase)
 	if !ok {
 		return fmt.Errorf("unexpected database type: %T", dtf.database)
 	}
@@ -451,7 +451,7 @@ func (dtf *DiffTableFunction) generateSchema(ctx *sql.Context, fromCommitVal, to
 
 // cacheTableDelta caches and returns an appropriate table delta for the table name given, taking renames into
 // consideration. Returns a sql.ErrTableNotFound if the given table name cannot be found in either revision.
-func (dtf *DiffTableFunction) cacheTableDelta(ctx *sql.Context, fromCommitVal, toCommitVal, dotCommitVal interface{}, tableName string, db Database) (diff.TableDelta, error) {
+func (dtf *DiffTableFunction) cacheTableDelta(ctx *sql.Context, fromCommitVal, toCommitVal, dotCommitVal interface{}, tableName string, db SqlDatabase) (diff.TableDelta, error) {
 	fromRefDetails, toRefDetails, err := loadDetailsForRefs(ctx, fromCommitVal, toCommitVal, dotCommitVal, db)
 	if err != nil {
 		return diff.TableDelta{}, err
