@@ -21,6 +21,7 @@ import (
 	"testing"
 
 	"github.com/dolthub/go-mysql-server/sql"
+	types2 "github.com/dolthub/go-mysql-server/sql/types"
 	"github.com/dolthub/vitess/go/sqltypes"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -48,23 +49,23 @@ func TestCreateTable(t *testing.T) {
 			query:         "create table testTable (id int primary key)",
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{})),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{})),
 		},
 		{
 			name:          "Test create two column schema",
 			query:         "create table testTable (id int primary key, age int)",
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, false)),
 		},
 		{
 			name:          "Test create two column keyless schema",
 			query:         "create table testTable (id int, age int)",
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, false),
-				schemaNewColumn(t, "age", 7208, sql.Int32, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, false),
+				schemaNewColumn(t, "age", 7208, types2.Int32, false)),
 		},
 		{
 			name:          "Test syntax error",
@@ -102,10 +103,10 @@ func TestCreateTable(t *testing.T) {
 								is_married boolean) `,
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, false),
-				schemaNewColumn(t, "first_name", 3264, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false),
-				schemaNewColumn(t, "is_married", 14626, sql.Boolean, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, false),
+				schemaNewColumn(t, "first_name", 3264, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false),
+				schemaNewColumn(t, "is_married", 14626, types2.Boolean, false)),
 		},
 		{
 			name:          "Test all supported types",
@@ -135,33 +136,33 @@ func TestCreateTable(t *testing.T) {
 							c25 mediumint unsigned,
 							c26 bigint unsigned)`,
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "c0", 594, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "c1", 601, sql.Int8, false),
-				schemaNewColumn(t, "c2", 14542, sql.Int16, false),
-				schemaNewColumn(t, "c3", 13309, sql.Int24, false),
-				schemaNewColumn(t, "c4", 15884, sql.Int32, false),
-				schemaNewColumn(t, "c5", 14619, sql.Int64, false),
-				schemaNewColumn(t, "c6", 13192, sql.Boolean, false),
-				schemaNewColumn(t, "c7", 5981, sql.Boolean, false),
-				schemaNewColumn(t, "c8", 14871, sql.MustCreateBitType(10), false),
-				schemaNewColumn(t, "c9", 4167, sql.Text, false),
-				schemaNewColumn(t, "c10", 1965, sql.TinyText, false),
-				schemaNewColumn(t, "c11", 12860, sql.MediumText, false),
-				schemaNewColumn(t, "c12", 7155, sql.LongText, false),
+				schemaNewColumn(t, "c0", 594, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "c1", 601, types2.Int8, false),
+				schemaNewColumn(t, "c2", 14542, types2.Int16, false),
+				schemaNewColumn(t, "c3", 13309, types2.Int24, false),
+				schemaNewColumn(t, "c4", 15884, types2.Int32, false),
+				schemaNewColumn(t, "c5", 14619, types2.Int64, false),
+				schemaNewColumn(t, "c6", 13192, types2.Boolean, false),
+				schemaNewColumn(t, "c7", 5981, types2.Boolean, false),
+				schemaNewColumn(t, "c8", 14871, types2.MustCreateBitType(10), false),
+				schemaNewColumn(t, "c9", 4167, types2.Text, false),
+				schemaNewColumn(t, "c10", 1965, types2.TinyText, false),
+				schemaNewColumn(t, "c11", 12860, types2.MediumText, false),
+				schemaNewColumn(t, "c12", 7155, types2.LongText, false),
 				//schemaNewColumn(t, "c13", 113, sql.TinyBlob, false),
 				//schemaNewColumn(t, "c14", 114, sql.Blob, false),
 				//schemaNewColumn(t, "c15", 115, sql.LongBlob, false),
-				schemaNewColumn(t, "c16", 15859, sql.MustCreateStringWithDefaults(sqltypes.Char, 5), false),
-				schemaNewColumn(t, "c17", 11710, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false),
-				schemaNewColumn(t, "c18", 6838, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
-				schemaNewColumn(t, "c19", 9377, sql.Float32, false),
-				schemaNewColumn(t, "c20", 15979, sql.Float64, false),
+				schemaNewColumn(t, "c16", 15859, types2.MustCreateStringWithDefaults(sqltypes.Char, 5), false),
+				schemaNewColumn(t, "c17", 11710, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false),
+				schemaNewColumn(t, "c18", 6838, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
+				schemaNewColumn(t, "c19", 9377, types2.Float32, false),
+				schemaNewColumn(t, "c20", 15979, types2.Float64, false),
 				//schemaNewColumn(t, "c21", 121, sql.MustCreateDecimalType(10, 5), false),
-				schemaNewColumn(t, "c22", 2910, sql.Uint32, false),
-				schemaNewColumn(t, "c23", 8740, sql.Uint8, false),
-				schemaNewColumn(t, "c24", 8689, sql.Uint16, false),
-				schemaNewColumn(t, "c25", 5243, sql.Uint24, false),
-				schemaNewColumn(t, "c26", 9338, sql.Uint64, false),
+				schemaNewColumn(t, "c22", 2910, types2.Uint32, false),
+				schemaNewColumn(t, "c23", 8740, types2.Uint8, false),
+				schemaNewColumn(t, "c24", 8689, types2.Uint16, false),
+				schemaNewColumn(t, "c25", 5243, types2.Uint24, false),
+				schemaNewColumn(t, "c26", 9338, types2.Uint64, false),
 			),
 		},
 		{
@@ -174,10 +175,10 @@ func TestCreateTable(t *testing.T) {
 								primary key (id, age))`,
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "first_name", 3264, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
-				schemaNewColumn(t, "is_married", 14626, sql.Boolean, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "first_name", 3264, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
+				schemaNewColumn(t, "is_married", 14626, types2.Boolean, false)),
 		},
 		{
 			name: "Test not null constraints",
@@ -189,10 +190,10 @@ func TestCreateTable(t *testing.T) {
 								primary key (id, age))`,
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "first_name", 3264, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "is_married", 14626, sql.Boolean, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "first_name", 3264, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "is_married", 14626, types2.Boolean, false)),
 		},
 		{
 			name: "Test quoted columns",
@@ -204,10 +205,10 @@ func TestCreateTable(t *testing.T) {
 				"primary key (`id`, `age`))",
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "timestamp", 10168, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
-				schemaNewColumn(t, "is married", 14626, sql.Boolean, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "timestamp", 10168, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
+				schemaNewColumn(t, "is married", 14626, types2.Boolean, false)),
 		},
 		{
 			name: "Test tag comments",
@@ -215,8 +216,8 @@ func TestCreateTable(t *testing.T) {
 								id int primary key, age int)`,
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, false)),
 		},
 		// Real world examples for regression testing
 		{
@@ -227,8 +228,8 @@ func TestCreateTable(t *testing.T) {
 							PRIMARY KEY (ip));`,
 			expectedTable: "ip2nation",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumnWDefVal(t, "ip", 7265, sql.Uint32, true, "0", schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "country", 6630, sql.MustCreateStringWithDefaults(sqltypes.Char, 2), false, `''`, schema.NotNullConstraint{})),
+				schemaNewColumnWDefVal(t, "ip", 7265, types2.Uint32, true, "0", schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "country", 6630, types2.MustCreateStringWithDefaults(sqltypes.Char, 2), false, `''`, schema.NotNullConstraint{})),
 		},
 		{
 			name:          "Test ip2nationCountries",
@@ -243,13 +244,13 @@ func TestCreateTable(t *testing.T) {
 							lon float NOT NULL default 0.0,
 							PRIMARY KEY (code));`,
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumnWDefVal(t, "code", 7802, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 4), true, `''`, schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "iso_code_2", 9266, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 2), false, `''`, schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "iso_code_3", 8427, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 3), false, `''`),
-				schemaNewColumnWDefVal(t, "iso_country", 7151, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false, `''`, schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "country", 879, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false, `''`, schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "lat", 3502, sql.Float32, false, "0.0", schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "lon", 9907, sql.Float32, false, "0.0", schema.NotNullConstraint{})),
+				schemaNewColumnWDefVal(t, "code", 7802, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 4), true, `''`, schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "iso_code_2", 9266, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 2), false, `''`, schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "iso_code_3", 8427, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 3), false, `''`),
+				schemaNewColumnWDefVal(t, "iso_country", 7151, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false, `''`, schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "country", 879, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false, `''`, schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "lat", 3502, types2.Float32, false, "0.0", schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "lon", 9907, types2.Float32, false, "0.0", schema.NotNullConstraint{})),
 		},
 	}
 
@@ -369,49 +370,49 @@ func TestAddColumn(t *testing.T) {
 			name:  "alter add string column no default",
 			query: "alter table people add (newColumn varchar(80))",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumn(t, "newColumn", 4208, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false)),
+				schemaNewColumn(t, "newColumn", 4208, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false)),
 			expectedRows: addColToRows(t, AllPeopleRows, 4208, nil),
 		},
 		{
 			name:  "alter add float column without default",
 			query: "alter table people add (newColumn float)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumn(t, "newColumn", 4208, sql.Float32, false)),
+				schemaNewColumn(t, "newColumn", 4208, types2.Float32, false)),
 			expectedRows: addColToRows(t, AllPeopleRows, 4208, nil),
 		},
 		{
 			name:  "alter add uint column without default",
 			query: "alter table people add (newColumn bigint unsigned)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumn(t, "newColumn", 4208, sql.Uint64, false)),
+				schemaNewColumn(t, "newColumn", 4208, types2.Uint64, false)),
 			expectedRows: addColToRows(t, AllPeopleRows, 4208, nil),
 		},
 		{
 			name:  "alter add int column default",
 			query: "alter table people add (newColumn int default 2)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumnWDefVal(t, "newColumn", 2803, sql.Int32, false, "2")),
+				schemaNewColumnWDefVal(t, "newColumn", 2803, types2.Int32, false, "2")),
 			expectedRows: addColToRows(t, AllPeopleRows, 2803, types.Int(int32(2))),
 		},
 		{
 			name:  "alter add uint column default",
 			query: "alter table people add (newColumn bigint unsigned default 20)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumnWDefVal(t, "newColumn", 517, sql.Uint64, false, "20")),
+				schemaNewColumnWDefVal(t, "newColumn", 517, types2.Uint64, false, "20")),
 			expectedRows: addColToRows(t, AllPeopleRows, 517, types.Uint(uint64(20))),
 		},
 		{
 			name:  "alter add string column with default",
 			query: "alter table people add (newColumn varchar(80) default 'hi')",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumnWDefVal(t, "newColumn", 13690, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, `'hi'`)),
+				schemaNewColumnWDefVal(t, "newColumn", 13690, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, `'hi'`)),
 			expectedRows: addColToRows(t, AllPeopleRows, 13690, types.String("hi")),
 		},
 		{
 			name:  "alter add column first",
 			query: "alter table people add newColumn varchar(80) first",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "newColumn", 4208, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
+				schemaNewColumn(t, "newColumn", 4208, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
 				schema.NewColumn("id", IdTag, types.IntKind, true, schema.NotNullConstraint{}),
 				schema.NewColumn("first_name", FirstNameTag, types.StringKind, false, schema.NotNullConstraint{}),
 				schema.NewColumn("last_name", LastNameTag, types.StringKind, false, schema.NotNullConstraint{}),
@@ -430,7 +431,7 @@ func TestAddColumn(t *testing.T) {
 				schema.NewColumn("id", IdTag, types.IntKind, true, schema.NotNullConstraint{}),
 				schema.NewColumn("first_name", FirstNameTag, types.StringKind, false, schema.NotNullConstraint{}),
 				schema.NewColumn("last_name", LastNameTag, types.StringKind, false, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "newColumn", 4208, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
+				schemaNewColumn(t, "newColumn", 4208, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
 				schema.NewColumn("is_married", IsMarriedTag, types.IntKind, false),
 				schema.NewColumn("age", AgeTag, types.IntKind, false),
 				schema.NewColumn("rating", RatingTag, types.FloatKind, false),
@@ -443,21 +444,21 @@ func TestAddColumn(t *testing.T) {
 			name:  "alter add column not null",
 			query: "alter table people add (newColumn varchar(80) not null default 'default')",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumnWDefVal(t, "newColumn", 13690, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, `'default'`, schema.NotNullConstraint{})),
+				schemaNewColumnWDefVal(t, "newColumn", 13690, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, `'default'`, schema.NotNullConstraint{})),
 			expectedRows: addColToRows(t, AllPeopleRows, 13690, types.String("default")),
 		},
 		{
 			name:  "alter add column not null with expression default",
 			query: "alter table people add (newColumn int not null default (2+2/2))",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumnWDefVal(t, "newColumn", 2803, sql.Int32, false, "((2 + (2 / 2)))", schema.NotNullConstraint{})),
+				schemaNewColumnWDefVal(t, "newColumn", 2803, types2.Int32, false, "((2 + (2 / 2)))", schema.NotNullConstraint{})),
 			expectedRows: addColToRows(t, AllPeopleRows, 2803, types.Int(3)),
 		},
 		{
 			name:  "alter add column not null with negative expression",
 			query: "alter table people add (newColumn float not null default -1.1)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumnWDefVal(t, "newColumn", 12469, sql.Float32, false, "-1.1", schema.NotNullConstraint{})),
+				schemaNewColumnWDefVal(t, "newColumn", 12469, types2.Float32, false, "-1.1", schema.NotNullConstraint{})),
 			expectedRows: addColToRows(t, AllPeopleRows, 12469, types.Float(float32(-1.1))),
 		},
 		{
@@ -479,21 +480,21 @@ func TestAddColumn(t *testing.T) {
 			name:  "alter add column not null without default",
 			query: "alter table people add (newColumn varchar(80) not null)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumnWDefVal(t, "newColumn", 13690, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, "", schema.NotNullConstraint{})),
+				schemaNewColumnWDefVal(t, "newColumn", 13690, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, "", schema.NotNullConstraint{})),
 			expectedRows: addColToRows(t, AllPeopleRows, 13690, types.String("")),
 		},
 		{
 			name:  "alter add column nullable",
 			query: "alter table people add (newColumn bigint)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumn(t, "newColumn", 4435, sql.Int64, false)),
+				schemaNewColumn(t, "newColumn", 4435, types2.Int64, false)),
 			expectedRows: AllPeopleRows,
 		},
 		{
 			name:  "alter add column with optional column keyword",
 			query: "alter table people add column (newColumn varchar(80))",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
-				schemaNewColumn(t, "newColumn", 4208, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false)),
+				schemaNewColumn(t, "newColumn", 4208, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false)),
 			expectedRows: AllPeopleRows,
 		},
 		{
@@ -879,22 +880,22 @@ func TestParseCreateTableStatement(t *testing.T) {
 			query:         "create table testTable (id int primary key)",
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{})),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{})),
 		},
 		{
 			name:          "Test create table starting with number",
 			query:         "create table 123table (id int primary key)",
 			expectedTable: "`123table`",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{})),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{})),
 		},
 		{
 			name:          "Test create two column schema",
 			query:         "create table testTable (id int primary key, age int)",
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, false)),
 		},
 		{
 			name:          "Test syntax error",
@@ -911,10 +912,10 @@ func TestParseCreateTableStatement(t *testing.T) {
 								is_married boolean) `,
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, false),
-				schemaNewColumn(t, "first_name", 3264, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false),
-				schemaNewColumn(t, "is_married", 14626, sql.Boolean, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, false),
+				schemaNewColumn(t, "first_name", 3264, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false),
+				schemaNewColumn(t, "is_married", 14626, types2.Boolean, false)),
 		},
 		{
 			name:          "Test all supported types",
@@ -944,33 +945,33 @@ func TestParseCreateTableStatement(t *testing.T) {
 							c25 mediumint unsigned,
 							c26 bigint unsigned)`,
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "c0", 594, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "c1", 601, sql.Int8, false),
-				schemaNewColumn(t, "c2", 14542, sql.Int16, false),
-				schemaNewColumn(t, "c3", 13309, sql.Int24, false),
-				schemaNewColumn(t, "c4", 15884, sql.Int32, false),
-				schemaNewColumn(t, "c5", 14619, sql.Int64, false),
-				schemaNewColumn(t, "c6", 13192, sql.Boolean, false),
-				schemaNewColumn(t, "c7", 5981, sql.Boolean, false),
-				schemaNewColumn(t, "c8", 14871, sql.MustCreateBitType(10), false),
-				schemaNewColumn(t, "c9", 4167, sql.Text, false),
-				schemaNewColumn(t, "c10", 1965, sql.TinyText, false),
-				schemaNewColumn(t, "c11", 12860, sql.MediumText, false),
-				schemaNewColumn(t, "c12", 7155, sql.LongText, false),
+				schemaNewColumn(t, "c0", 594, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "c1", 601, types2.Int8, false),
+				schemaNewColumn(t, "c2", 14542, types2.Int16, false),
+				schemaNewColumn(t, "c3", 13309, types2.Int24, false),
+				schemaNewColumn(t, "c4", 15884, types2.Int32, false),
+				schemaNewColumn(t, "c5", 14619, types2.Int64, false),
+				schemaNewColumn(t, "c6", 13192, types2.Boolean, false),
+				schemaNewColumn(t, "c7", 5981, types2.Boolean, false),
+				schemaNewColumn(t, "c8", 14871, types2.MustCreateBitType(10), false),
+				schemaNewColumn(t, "c9", 4167, types2.Text, false),
+				schemaNewColumn(t, "c10", 1965, types2.TinyText, false),
+				schemaNewColumn(t, "c11", 12860, types2.MediumText, false),
+				schemaNewColumn(t, "c12", 7155, types2.LongText, false),
 				//schemaNewColumn(t, "c13", 113, sql.TinyBlob, false),
 				//schemaNewColumn(t, "c14", 114, sql.Blob, false),
 				//schemaNewColumn(t, "c15", 115, sql.LongBlob, false),
-				schemaNewColumn(t, "c16", 15859, sql.MustCreateStringWithDefaults(sqltypes.Char, 5), false),
-				schemaNewColumn(t, "c17", 11710, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false),
-				schemaNewColumn(t, "c18", 6838, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
-				schemaNewColumn(t, "c19", 9377, sql.Float32, false),
-				schemaNewColumn(t, "c20", 15979, sql.Float64, false),
+				schemaNewColumn(t, "c16", 15859, types2.MustCreateStringWithDefaults(sqltypes.Char, 5), false),
+				schemaNewColumn(t, "c17", 11710, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false),
+				schemaNewColumn(t, "c18", 6838, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
+				schemaNewColumn(t, "c19", 9377, types2.Float32, false),
+				schemaNewColumn(t, "c20", 15979, types2.Float64, false),
 				//schemaNewColumn(t, "c21", 121, sql.MustCreateDecimalType(10, 5), false),
-				schemaNewColumn(t, "c22", 2910, sql.Uint32, false),
-				schemaNewColumn(t, "c23", 8740, sql.Uint8, false),
-				schemaNewColumn(t, "c24", 8689, sql.Uint16, false),
-				schemaNewColumn(t, "c25", 5243, sql.Uint24, false),
-				schemaNewColumn(t, "c26", 9338, sql.Uint64, false),
+				schemaNewColumn(t, "c22", 2910, types2.Uint32, false),
+				schemaNewColumn(t, "c23", 8740, types2.Uint8, false),
+				schemaNewColumn(t, "c24", 8689, types2.Uint16, false),
+				schemaNewColumn(t, "c25", 5243, types2.Uint24, false),
+				schemaNewColumn(t, "c26", 9338, types2.Uint64, false),
 			),
 		},
 		{
@@ -983,10 +984,10 @@ func TestParseCreateTableStatement(t *testing.T) {
 								primary key (id, age))`,
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "first_name", 3264, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
-				schemaNewColumn(t, "is_married", 14626, sql.Boolean, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "first_name", 3264, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
+				schemaNewColumn(t, "is_married", 14626, types2.Boolean, false)),
 		},
 		{
 			name: "Test not null constraints",
@@ -998,10 +999,10 @@ func TestParseCreateTableStatement(t *testing.T) {
 								primary key (id, age))`,
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "first_name", 3264, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "is_married", 14626, sql.Boolean, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "first_name", 3264, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "is_married", 14626, types2.Boolean, false)),
 		},
 		{
 			name: "Test quoted columns",
@@ -1013,10 +1014,10 @@ func TestParseCreateTableStatement(t *testing.T) {
 				"primary key (`id`, `age`))",
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "timestamp", 10168, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
-				schemaNewColumn(t, "is married", 14626, sql.Boolean, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "timestamp", 10168, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false),
+				schemaNewColumn(t, "is married", 14626, types2.Boolean, false)),
 		},
 		{
 			name: "Test tag comments",
@@ -1024,8 +1025,8 @@ func TestParseCreateTableStatement(t *testing.T) {
 								id int primary key, age int)`,
 			expectedTable: "testTable",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumn(t, "id", 4817, sql.Int32, true, schema.NotNullConstraint{}),
-				schemaNewColumn(t, "age", 7208, sql.Int32, false)),
+				schemaNewColumn(t, "id", 4817, types2.Int32, true, schema.NotNullConstraint{}),
+				schemaNewColumn(t, "age", 7208, types2.Int32, false)),
 		},
 		// Real world examples for regression testing
 		{
@@ -1036,8 +1037,8 @@ func TestParseCreateTableStatement(t *testing.T) {
 							PRIMARY KEY (ip));`,
 			expectedTable: "ip2nation",
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumnWDefVal(t, "ip", 7265, sql.Uint32, true, "0", schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "country", 6630, sql.MustCreateStringWithDefaults(sqltypes.Char, 2), false, `''`, schema.NotNullConstraint{})),
+				schemaNewColumnWDefVal(t, "ip", 7265, types2.Uint32, true, "0", schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "country", 6630, types2.MustCreateStringWithDefaults(sqltypes.Char, 2), false, `''`, schema.NotNullConstraint{})),
 		},
 		{
 			name:          "Test ip2nationCountries",
@@ -1052,13 +1053,13 @@ func TestParseCreateTableStatement(t *testing.T) {
 							lon float NOT NULL default 0.0,
 							PRIMARY KEY (code));`,
 			expectedSchema: dtestutils.CreateSchema(
-				schemaNewColumnWDefVal(t, "code", 7802, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 4), true, `''`, schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "iso_code_2", 9266, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 2), false, `''`, schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "iso_code_3", 8427, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 3), false, `''`),
-				schemaNewColumnWDefVal(t, "iso_country", 7151, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false, `''`, schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "country", 879, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false, `''`, schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "lat", 3502, sql.Float32, false, "0.0", schema.NotNullConstraint{}),
-				schemaNewColumnWDefVal(t, "lon", 9907, sql.Float32, false, "0.0", schema.NotNullConstraint{})),
+				schemaNewColumnWDefVal(t, "code", 7802, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 4), true, `''`, schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "iso_code_2", 9266, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 2), false, `''`, schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "iso_code_3", 8427, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 3), false, `''`),
+				schemaNewColumnWDefVal(t, "iso_country", 7151, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false, `''`, schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "country", 879, types2.MustCreateStringWithDefaults(sqltypes.VarChar, 255), false, `''`, schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "lat", 3502, types2.Float32, false, "0.0", schema.NotNullConstraint{}),
+				schemaNewColumnWDefVal(t, "lon", 9907, types2.Float32, false, "0.0", schema.NotNullConstraint{})),
 		},
 	}
 
